Register Account
Description: Tips for a Debian GNU/Linux System Administrator.
Keywords: Debian System Administration News, Debian Sysadmin, Linux Administration, Linux Sysadmin, Sysadmin

# Debian Administration

- About
- Archive
- Contribute
- FAQ
- Search
- Tags

# Create a new user account

To register an account please fill out the following details:

Username: |
Email Address: |

Your email address is needed to send you your password. If you wish you can also receive email notification of new replies to any articles and comments you post.

Please make sure it is a valid email address and you have entered it correctly, if you make a mistake you will create an account you cannot use - and you will have to choose another username.

We do not and will not sell, trade, or otherwise disclose our users' email addresses to anyone, for any reason, ever. Your email address will not be displayed publicly upon the website, unless you choose to add it yourself.

#### Sign In

Username:

Password:

[Register|Advanced]

### Flattr

### Current Poll

What do you use for configuration management?

Chef
Puppet
SaltStack
CFEngine
Other tool
Nothing
( 754 votes ~ 10 comments )

### Recent Weblogs

It's been 7 Years
by rkreider
GnuPG 2.1.0 in debian experimental
by dkg
8 comments
Site code is public once again.
by Steve
1 comment
Using Amazon SES with Exim (Submission)
by lee
Web Application Vulnerability scanners
by simonw
Strange Dovecot behaviour solved
by ajt
1 comment
Problem with Bonding and Vlan on Wheezy
by fugit
1 comment
I have a Debian server again
by blackm
Hello World!
by cisco
Planning for Disk Encryption
by tong

Archived weblogs